@@ -6,14 +6,37 @@
 #define __hidden
 
 // variadic macros added in vc 8.0: http://msdn.microsoft.com/en-us/library/ms177415(VS.80).aspx
-#define _null_call(...) do {} while(0)
-#define _dbg_printf(format, ...) do { fprintf(stderr , format , __VA_ARGS__);  } while(0)
-// dbg_printf gets redefined to _dbg_printf on a source file by source file basis
 
-#ifdef DEBUG_OUTPUT_ALL
+
+#define _env_dbg_printf(env, format, ...) \
+    do { \
+        char w[256] = "LIBSMBIOS_C_"; \
+        strncat(w, env, 256 - 1 - strlen(w));   \
+        const char *v = 0;  \
+        const char *u = getenv("LIBSMBIOS_C_DEBUG_OUTPUT_ALL");    \
+        if (env) v = getenv(w);    \
+        if ( (u && atoi(u) > 0) || (v && atoi(v) > 0) ) {   \
+        fprintf(stderr , format , __VA_ARGS__); \
+        fflush(NULL); \
+        }\
+    } while(0)
+
+#define _stderr_dbg_printf(format, ...) do { fprintf(stderr , format , __VA_ARGS__);  } while(0)
+
+#define _null_call(...) do {} while(0)
+
+// default to env-controlled
+#if !defined(DEBUG_OUTPUT_ALL) && !defined(SUPRESS_DEBUGGING_OUTPUT)
 #include <stdio.h>
-#define dbg_printf _dbg_printf
-#else
+#include <string.h>
+#include <stdlib.h>
+#  define dbg_printf(args...) _env_dbg_printf( DEBUG_MODULE_NAME, ## args )
+
+#elif defined(DEBUG_OUTPUT_ALL)
+#  include <stdio.h>
+#  define dbg_printf _stderr_dbg_printf
+
+#elif defined(SUPRESS_DEBUGGING_OUTPUT)
 #define dbg_printf _null_call
 #endif
 
